@@ -44,13 +44,6 @@ parser_main.add_argument(
         "only the ID of items created instead of the full object."
     ),
 )
-parser_main.add_argument(
-    "-j",
-    "--json",
-    default=False,
-    action="store_true",
-    help="Output raw json",
-)
 
 subparsers_main = parser_main.add_subparsers(title="Commands:", dest="cmd")
 
@@ -260,6 +253,40 @@ task_check_collection_parser.add_argument(
     help="Also include task-collection logs",
 )
 
+# task new
+task_new_parser = task_subparsers.add_parser(
+    "new", description="Create new task", argument_default=ap.SUPPRESS
+)
+task_new_parser.add_argument(
+    "name", help="A human readable name for the task", type=str
+)
+task_new_parser.add_argument(
+    "command", help="The command that executes the task", type=str
+)
+task_new_parser.add_argument("source", help="TBD", type=str)
+task_new_parser.add_argument(
+    "--input-type",
+    help="The type of data the task expects as input",
+    type=str,
+    default="Any",
+)
+task_new_parser.add_argument(
+    "--output-type",
+    help="The type of data the task expects as output",
+    type=str,
+    default="Any",
+)
+task_new_parser.add_argument(
+    "--default-args-file",
+    help="Path to JSON file with default task arguments",
+    type=str,
+)
+task_new_parser.add_argument(
+    "--meta-file",
+    help="Path to JSON file with additional parameters useful for execution",
+    type=str,
+)
+
 # task edit
 task_edit_parser = task_subparsers.add_parser(
     "edit", description="Edit task", argument_default=ap.SUPPRESS
@@ -339,11 +366,6 @@ workflow_edit_parser.add_argument(
     help="Workflow ID",
 )
 workflow_edit_parser.add_argument("--name", type=str, help="New workflow name")
-workflow_edit_parser.add_argument(
-    "--project-id",
-    type=int,
-    help="ID of the project to be associated with the current workflow",
-)
 
 # workflow delete
 workflow_delete_parser = workflow_subparsers.add_parser(
@@ -452,6 +474,36 @@ workflow_apply_parser.add_argument(
     help="Command to be run before starting a worker",
 )
 
+# workflow import
+workflow_import_parser = workflow_subparsers.add_parser(
+    "import",
+    description="Import workflow to project from file",
+)
+workflow_import_parser.add_argument(
+    "--project-id",
+    help="ID of the project where the workflow will be imported",
+    required=True,
+)
+workflow_import_parser.add_argument(
+    "--json-file",
+    help="Path to a JSON file with the workflow to be imported",
+)
+
+# workflow export
+workflow_export_parser = workflow_subparsers.add_parser(
+    "export",
+    description="Export workflow to file",
+)
+workflow_export_parser.add_argument(
+    "--workflow-id",
+    help="Workflow ID",
+    required=True,
+)
+workflow_export_parser.add_argument(
+    "--json-file",
+    help="Path to the JSON file where the workflow will be exported",
+    required=True,
+)
 
 # JOB GROUP
 
